@@ -3,7 +3,7 @@
 
 
 package BeamerReveal::MediaManager;
-our $VERSION = '20251227.1144'; # VERSION
+our $VERSION = '20251227.1256'; # VERSION
 
 use strict;
 use warnings;
@@ -191,7 +191,13 @@ sub animationToStore {
 	 sub {
 	   my ( $plan ) = @_;
 	   my $cmd;
+	   my $logFile = IO::File->new();
 	   my $coreId = sprintf( '%0' . nofdigits( $nofCores ) . 'd', $plan->{nr} );
+	   my $logFileName = "animation-$coreId-overall.log";
+	   $logFile->open( ">$logFileName" )
+	     or die( "Error: cannot open logfile $logFileName" );
+
+	   say $logFile "- Generating TeX file";
 	   # generate TeX -file
 	   my $perCoreContent = BeamerReveal::TemplateStore::stampTemplate
 	     ( $fileContent,
@@ -208,12 +214,14 @@ sub animationToStore {
 	     or die( "Error: cannot open animation file '$texFileName' for writing\n" );
 	   print $texFile $perCoreContent;
 	   $texFile->close();
-	   
+
+	   say $logFile "- Running TeX";
 	   # run TeX
 	   $cmd = [ $self->{compiler},
 		    "--output-directory=$animdir", "$texFileName" ];
 	   BeamerReveal::IPC::Run::run( $cmd, $coreId, 8 );
 
+	   say $logFile "- Cropping PDF file";
 	   # run pdfcrop
 	   $cmd = [ $self->{pdfcrop}, '--margins', '-2', "animation-$coreId.pdf" ];
 	   BeamerReveal::IPC::Run::run( $cmd, $coreId, 8, $animdir );
@@ -222,6 +230,7 @@ sub animationToStore {
 	   my $xrange = 2 * int( $self->{presentationparameters}->{canvaswidth} * $animation->{width} );
 	   my $yrange = 2 * int( $self->{presentationparameters}->{canvasheight} * $animation->{height} );
 	   
+	   say $logFile "- Generating jpg files";
 	   $cmd = [ $self->{pdftoppm},
 		    '-scale-to-x', "$xrange",
 		    '-scale-to-y', "$yrange",
@@ -229,6 +238,7 @@ sub animationToStore {
 	   BeamerReveal::IPC::Run::run( $cmd, $coreId, 8, $animdir );
 
 	   # correct for too short slicesize in filenames coming from pdftoppm
+	   say $logFile "- Cleaning up jpg files";
 	   my $currentDigitCnt = nofdigits( $plan->{slicestop} );
 	   my $desiredDigitCnt = nofdigits( $sliceSize );
 	   if ( $currentDigitCnt < $desiredDigitCnt ) {
@@ -240,6 +250,7 @@ sub animationToStore {
 	       File::Copy::move( $src, $dst );
 	     }
 	   }
+	   $logFile->close();
 	 }, $planning->[$i] );
     }
     
@@ -347,7 +358,7 @@ BeamerReveal::MediaManager - MediaManager
 
 =head1 VERSION
 
-version 20251227.1144
+version 20251227.1256
 
 =head1 SYNOPSIS
 
